Python: module TileStache.Goodies.VecTiles.geojson

TileStache.Goodies.VecTiles.geojson | index

Modules
`` |  |
json |  |  |

Functions
`` |  | ceil(...) `ceil(x) Return the ceiling of x as a float. This is the smallest integral value >= x.` decode(file) `Decode a GeoJSON file into a list of (WKB, property dict) features. Result can be passed directly to mapnik.PythonDatasource.wkb_features().` encode(file, features, zoom, is_clipped) `Encode a list of (WKB, property dict) features into a GeoJSON stream. Also accept three-element tuples as features: (WKB, property dict, id). Geometries in the features list are assumed to be unprojected lon, lats. Floating point precision in the output is truncated to six digits.` get_tiles(names, config, coord) `Retrieve a list of named GeoJSON layer tiles from a TileStache config. Check integrity and compatibility of each, looking at known layers, correct JSON mime-types and "FeatureCollection" in the type attributes.` log(...) `log(x[, base]) Return the logarithm of x to the given base. If the base not specified, returns the natural logarithm (base e) of x.` mercator((x, y)) `Project an (x, y) tuple to spherical mercator.` merge(file, names, config, coord) `Retrieve a list of GeoJSON tile responses and merge them into one. get_tiles() retrieves data and performs basic integrity checks.` tan(...) `tan(x) Return the tangent of x (measured in radians).`

Data
`` |  | charfloat_pat = <_sre.SRE_Pattern object> float_pat = <_sre.SRE_Pattern object> pi = 3.141592653589793 precisions = [2, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 5, 6, 6, 6, 7, 7, 7, ...] zoom = 22